# 🌤️ WeatherUZ — O'zbekiston ob-havo ma'lumotlari uchun Python kutubxonasi  

**WeatherUZ** — bu O'zbekistonning zamonaviy **ob-havo** ma'lumotlarini olish uchun yaratilgan **Python kutubxonasi**!  
U sizga istalgan vaqtda **shaharlar bo‘yicha aniq ma’lumotlarni olish** imkonini beradi.  

📌 **Qulayliklar:**  
✅ Oddiy va oson ishlatiladigan API  
✅ Eng dolzarb ob-havo ma'lumotlari 🌦️  
✅ O'zbekistondagi barcha yirik shaharlarga moslashgan 🌎  

---

## 📍 Qo‘llab-quvvatlanadigan shaharlar

- **Toshkent** (Tashkent)  
- **Andijon** (Andijan)  
- **Buxoro** (Bukhara)  
- **Guliston** (Gulistan)  
- **Jizzax** (Jizzakh)  
- **Zarafshon** (Zarafshan)  
- **Qarshi** (Karshi)  
- **Navoiy** (Navoi)  
- **Namangan**  
- **Nukus**  
- **Samarqand** (Samarkand)  
- **Termiz** (Termez)  
- **Urganch** (Urgench)  
- **Farg‘ona** (Ferghana)  
- **Xiva** (Khiva)  
- **Sir Daryo** (Sirdarya)  
- **Surxondaryo** (Surkhandarya)  
- **Qashqadaryo** (Kashkadarya)  
- **Xorazm** (Khorezm)  

---

## 🚀 O'rnatish  

WeatherUZ kutubxonasini **PyPI** orqali o‘rnatish juda oson:  

```bash
pip install weatheruz
